@@ -17,6 +17,7 @@ from graphqlclient import GraphQLClient
 
 from .constant import BASKING_API_URL
 from .queries import *
+from .utils import deprecated
 
 
 @dataclass
@@ -34,6 +35,7 @@ class Authentication:
 
 class GraphqlQuery:
     """
+    # TODO: Deprecate all static methods in favor of a query class
     graphql_query class
     """
     _ggraphql_client = None
@@ -108,13 +110,10 @@ class GraphqlQuery:
         except HTTPError:
             self.log.error('API server error', exc_info=True)
 
-    # TODO: Deprecate all static methods in favor of a query class
     @staticmethod
     def get_building_occupancy_stats_daily_graphql_query(building_id, start_date, end_date) -> (str, dict):
-
         """graphql query for get_building_occupancy_stats_daily function
         :return: graphql query, variables
-
         """
         variables = {
             'id': str(building_id),
@@ -152,7 +151,6 @@ class GraphqlQuery:
             'from': start_date.strftime(GraphqlQuery.DATE_FORMAT),
             'to': end_date.strftime(GraphqlQuery.DATE_FORMAT),
             "floorAreaId": 0,
-            "floorId": 0
         }
 
         return GET_LOCATION_OCCUPANCY_HOURLY, variables
