@@ -26,6 +26,7 @@ GET_ORG_VISIT_FREQ = """
         }
         """
 
+# TODO: `lastCount` is deprecated and will be removed from the API during 02/2023
 GET_LOCATION_STATS_DAILY = """
                     query get_building_occupancy_stats_daily(
                         $id: ID!,
@@ -40,7 +41,6 @@ GET_LOCATION_STATS_DAILY = """
                                 ) {
                                     date, 
                                     peakCount,
-                                    lastCount,
                                     avgCount,
                                     adjustedCapacity: capacity,
                                     adjustedCapacityPct: capacityPct,
@@ -88,7 +88,7 @@ GET_LOCATION_OCCUPANCY_HOURLY = """
                         $id: ID!,
                         $from: DateTime!,
                         $to: DateTime!,
-                        $floorId: Int,
+                        $floorId: String,
                         $floorAreaId: Int,
                     ) {
                         location(id: $id) {
